/*
 * Copyright (c) 2016 Intel Corporation
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr/kernel.h>
#include <zephyr/drivers/gpio.h>

/* 1000 msec = 1 sec */
#define SLEEP_TIME_MS   1000

/* The devicetree node identifier for the "led0" and "led1" alias. */
#define LED0_NODE DT_ALIAS(led0)
#define LED1_NODE DT_ALIAS(led1)

/*
 * A build error on this line means your board is unsupported.
 * See the sample documentation for information on how to fix this.
 */
static const struct gpio_dt_spec led_0 = GPIO_DT_SPEC_GET(LED0_NODE, gpios);
static const struct gpio_dt_spec led_1 = GPIO_DT_SPEC_GET(LED1_NODE, gpios);

// Basing the sensor stuff on this: https://github.com/nrfconnect/sdk-zephyr/blob/main/samples/shields/x_nucleo_iks01a3/standard/src/main.c or https://github.com/nrfconnect/sdk-zephyr/blob/main/drivers/sensor/st/lis2dw12/lis2dw12.c#L11
#include <zephyr/drivers/sensor.h>
#include <zephyr/device.h>

const struct device *const lis2dw12 = DEVICE_DT_GET_ONE(st_lis2dw12);

static void lis2dw12_config(const struct device *lis2dw12)
{
	struct sensor_value odr_attr, fs_attr;

	/* set LIS2DW12 accel/gyro sampling frequency to 100 Hz */
	odr_attr.val1 = 100;
	odr_attr.val2 = 0;

	if (sensor_attr_set(lis2dw12, SENSOR_CHAN_ACCEL_XYZ,
			    SENSOR_ATTR_SAMPLING_FREQUENCY, &odr_attr) < 0) {
		printk("Cannot set sampling frequency for LIS2DW12 accel\n");
		return;
	}

	sensor_g_to_ms2(16, &fs_attr);

	if (sensor_attr_set(lis2dw12, SENSOR_CHAN_ACCEL_XYZ,
			    SENSOR_ATTR_FULL_SCALE, &fs_attr) < 0) {
		printk("Cannot set sampling frequency for LIS2DW12 gyro\n");
		return;
	}
}

int main(void)
{
	int ret;

	if (!gpio_is_ready_dt(&led_0)) {
		return 0;
	}
    if (!gpio_is_ready_dt(&led_1)) {
		return 0;
	}

	ret = gpio_pin_configure_dt(&led_0, GPIO_OUTPUT_ACTIVE);
	if (ret < 0) {
		return 0;
	}
    ret = gpio_pin_configure_dt(&led_1, GPIO_OUTPUT_ACTIVE);
	if (ret < 0) {
		return 0;
	}
    gpio_pin_set_dt(&led_0, 0);
    gpio_pin_set_dt(&led_1, 1);

    // Sensor config 
    const struct device *const lis2dw12 = DEVICE_DT_GET_ONE(st_lis2dw12);
    if (!device_is_ready(lis2dw12)) {
		printk("%s: device not ready.\n", lis2dw12->name);
		return 0;
	}
    lis2dw12_config(lis2dw12);
    
	while (1) {
		ret = gpio_pin_toggle_dt(&led_0);
        if (ret < 0) {
			return 0;
		}
        ret = gpio_pin_toggle_dt(&led_1);
		if (ret < 0) {
			return 1;
		}
		k_msleep(SLEEP_TIME_MS);
	}
	return 0;
}
